https://sherpa-ai.readthedocs.io/en/latest/

# Sherpa AI Github
1. https://github.com/Aggregate-Intellect/sherpa
2. https://aisc.substack.com/
3. https://aisc.substack.com/p/llm-agents-part-4-workflow-to-multi
4. https://aisc.substack.com/s/ai-llms/archive?sort=new

# Sherpa AI Architecture
```
┌────────────┐
│   Input    │
└─────┬──────┘
│
▼
┌───────────────────────────────────────┐
│              Agent                    │
└───┬───────────────┬──────────────┬────┘
│               │              │
▼               ▼              ▼
┌───────┐      ┌────────┐     ┌────────┐
│ Model │      │ Memory │     │ Policy │
└───┬───┘      └────────┘     └────┬───┘
│                              │
▼                              │
┌───────┐                          │
│ Prompt│                          │
└───┬───┘                          │
│                              │
▼                              │
┌───────┐                          │
│Actions│◄─────────────────────────┘
└───┬───┘
│
▼
┌───────┐
│ Tools │
└───────┘

```

# Venture Studio Models ?
```angular2html

I have idea to incuement a venture studio model that can be used to create new startups. The model will be able to generate ideas, validate them, and even create a business plan. The model will be able to use the Sherpa AI architecture to create a startup from scratch.

```

# Evolution of LLM Products

1. UI---> LLM --->( ChatGPT)
2. UI ---> LLM ---> DATA (RAG)---> ( BABY RAG) 
3. UI ---> LLM Security, Privacy,Relevance,Refinement ,Guardrail --> DATA , WOrking memory ---> Proper RAG
4. UI ---> LLM ---> DATA ---> RAG ---> AGENT (Sherpa AI)


## Agent-1
1. Multi-Agents
2. Multi-Player Systems

## LLMS
1. Langugage SKILLS
- NLU ,Natural Lanauage 
2. Tool USE -->
3. Reasoning SKILLS--> Task Decomposition, Planning, Execution
4. Memory SKILLS

